[Libreoffice-commits] .: 3 commits - sw/inc sw/prj sw/source

Fridrich Strba fridrich at kemper.freedesktop.org
Sun Feb 6 02:58:46 PST 2011


 sw/inc/IDocumentExternalData.hxx           |    4 ++--
 sw/inc/SwStyleNameMapper.hxx               |    4 ++--
 sw/inc/dbgoutsw.hxx                        |    8 ++++----
 sw/inc/doc.hxx                             |    6 +++---
 sw/inc/numrule.hxx                         |    8 ++++----
 sw/prj/build.lst                           |    2 +-
 sw/source/core/access/accpara.hxx          |    4 ++--
 sw/source/core/doc/docnew.cxx              |    2 +-
 sw/source/core/doc/docnum.cxx              |    4 ++--
 sw/source/core/doc/number.cxx              |    4 ++--
 sw/source/core/doc/swstylemanager.cxx      |    4 ++--
 sw/source/core/inc/layouter.hxx            |    4 ++--
 sw/source/core/unocore/unocoll.cxx         |    2 +-
 sw/source/filter/ww8/WW8TableInfo.hxx      |    8 ++++----
 sw/source/filter/ww8/hash_wrap.hxx         |   10 +++++-----
 sw/source/filter/ww8/wrtww8.cxx            |    2 +-
 sw/source/filter/ww8/ww8par.cxx            |    4 ++--
 sw/source/filter/xml/xmlimp.cxx            |    4 ++--
 sw/source/filter/xml/xmltbli.cxx           |    2 +-
 sw/source/filter/xml/xmltbli.hxx           |    4 ++--
 sw/source/ui/vba/vbadocumentproperties.cxx |    6 +++---
 sw/source/ui/vba/vbadocumentproperties.hxx |    2 +-
 sw/source/ui/vba/vbadocuments.cxx          |    2 +-
 sw/source/ui/vba/vbafont.cxx               |    4 ++--
 24 files changed, 52 insertions(+), 52 deletions(-)

New commits:
commit f3aef4dca34c5085a73a65b3ab92be10878bfb75
Author: Fridrich Å trba <fridrich.strba at bluewin.ch>
Date:   Sun Feb 6 10:38:51 2011 +0100

    sw unit tests need libunoxml

diff --git a/sw/prj/build.lst b/sw/prj/build.lst
index e61ab62..a71a1d7 100755
--- a/sw/prj/build.lst
+++ b/sw/prj/build.lst
@@ -1,4 +1,4 @@
-sw      sw      :    filter l10n connectivity writerperfect lotuswordpro vbahelper svx stoc writerfilter NULL
+sw      sw      :    filter l10n connectivity writerperfect lotuswordpro vbahelper svx stoc writerfilter unoxml NULL
 sw	sw										usr1	-	all	sw_mkout NULL
 sw	sw\inc									nmake		-	all	sw_inc NULL
 sw	sw\uiconfig\layout									nmake	-	all	sw_layout NULL
commit 89fbc178575ac65d2a036633de22f6ad7e2c22f6
Author: Fridrich Å trba <fridrich.strba at bluewin.ch>
Date:   Sun Feb 6 01:17:23 2011 +0100

    also the std::hash_set

diff --git a/sw/source/filter/ww8/wrtww8.cxx b/sw/source/filter/ww8/wrtww8.cxx
index d1cf62a..530bc87 100644
--- a/sw/source/filter/ww8/wrtww8.cxx
+++ b/sw/source/filter/ww8/wrtww8.cxx
@@ -2442,7 +2442,7 @@ struct SwNodeHash
     size_t operator()(SwNode * pNode) const { return reinterpret_cast<size_t>(pNode); }
 };
 
-typedef ::std::hash_set<SwNode *, SwNodeHash> SwNodeHashSet;
+typedef ::boost::unordered_set<SwNode *, SwNodeHash> SwNodeHashSet;
 typedef ::std::deque<SwNode *> SwNodeDeque;
 #endif
 
diff --git a/sw/source/filter/ww8/ww8par.cxx b/sw/source/filter/ww8/ww8par.cxx
index 601108b..1f53648 100644
--- a/sw/source/filter/ww8/ww8par.cxx
+++ b/sw/source/filter/ww8/ww8par.cxx
@@ -29,7 +29,7 @@
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_sw.hxx"
 
-#include <hash_set>
+#include <boost/unordered_set.hpp>
 #include <com/sun/star/embed/ElementModes.hpp>
 #include <com/sun/star/embed/XStorage.hpp>
 #include <unotools/ucbstreamhelper.hxx>
@@ -1266,7 +1266,7 @@ void SwWW8ImplReader::Read_Tab(USHORT , const BYTE* pData, short nLen)
     }
 
     bool bFound = false;
-    ::std::hash_set<size_t> aLoopWatch;
+    ::boost::unordered_set<size_t> aLoopWatch;
     while (pSty && !bFound)
     {
         const SfxPoolItem* pTabs;
diff --git a/sw/source/filter/xml/xmlimp.cxx b/sw/source/filter/xml/xmlimp.cxx
index 4d32313..00d376b 100644
--- a/sw/source/filter/xml/xmlimp.cxx
+++ b/sw/source/filter/xml/xmlimp.cxx
@@ -64,7 +64,7 @@
 #include <xmloff/xmluconv.hxx>
 #include <unotools/saveopt.hxx>
 #include <tools/diagnose_ex.h>
-#include <hash_set>
+#include <boost/unordered_set.hpp>
 #include <stringhash.hxx>
 
 // for locking SolarMutex: svapp + mutex
@@ -1163,7 +1163,7 @@ void SwXMLImport::SetConfigurationSettings(const Sequence < PropertyValue > & aC
     if( !xInfo.is() )
         return;
 
-    hash_set< String, StringHashRef, StringEqRef > aSet;
+    boost::unordered_set< String, StringHashRef, StringEqRef > aSet;
     aSet.insert(String("ForbiddenCharacters", RTL_TEXTENCODING_ASCII_US));
     aSet.insert(String("IsKernAsianPunctuation", RTL_TEXTENCODING_ASCII_US));
     aSet.insert(String("CharacterCompressionType", RTL_TEXTENCODING_ASCII_US));
commit 56ee10ba87a15adf2911e1ef1de1cdd0efc1ffe9
Author: Fridrich Å trba <fridrich.strba at bluewin.ch>
Date:   Sun Feb 6 00:58:27 2011 +0100

    port repository writer to boost unordered containers

diff --git a/sw/inc/IDocumentExternalData.hxx b/sw/inc/IDocumentExternalData.hxx
index b75ccbc..629a2e2 100644
--- a/sw/inc/IDocumentExternalData.hxx
+++ b/sw/inc/IDocumentExternalData.hxx
@@ -28,7 +28,7 @@
 #ifndef INCLUDED_I_DOCUMENT_EXTERNAL_DATA_HXX
 #define INCLUDED_I_DOCUMENT_EXTERNAL_DATA_HXX
 
-#include <hash_map>
+#include <boost/unordered_map.hpp>
 #include <boost/shared_ptr.hpp>
 
 namespace sw
@@ -54,7 +54,7 @@ typedef ::boost::shared_ptr<ExternalData> tExternalDataPointer;
 class IDocumentExternalData
 {
 protected:
-    typedef ::std::hash_map<sw::tExternalDataType, sw::tExternalDataPointer, sw::ExternalDataTypeHash> 
+    typedef ::boost::unordered_map<sw::tExternalDataType, sw::tExternalDataPointer, sw::ExternalDataTypeHash>
     tExternalData;
 
     tExternalData m_externalData;
diff --git a/sw/inc/SwStyleNameMapper.hxx b/sw/inc/SwStyleNameMapper.hxx
index 429c5f3..03db252 100644
--- a/sw/inc/SwStyleNameMapper.hxx
+++ b/sw/inc/SwStyleNameMapper.hxx
@@ -34,7 +34,7 @@
 #include "swdllapi.h"
 
 #ifndef INCLUDED_HASH_MAP
-#include <hash_map>
+#include <boost/unordered_map.hpp>
 #define INCLUDED_HASH_MAP
 #endif
 #include <stringhash.hxx>
@@ -88,7 +88,7 @@ class String;
 struct SwTableEntry;
 
 
-typedef ::std::hash_map < const String*, sal_uInt16, StringHash, StringEq > NameToIdHash;
+typedef ::boost::unordered_map < const String*, sal_uInt16, StringHash, StringEq > NameToIdHash;
 
 class SwStyleNameMapper
 {
diff --git a/sw/inc/dbgoutsw.hxx b/sw/inc/dbgoutsw.hxx
index 2dec2d9..71088ea 100644
--- a/sw/inc/dbgoutsw.hxx
+++ b/sw/inc/dbgoutsw.hxx
@@ -30,7 +30,7 @@
 
 #ifdef DEBUG
 
-#include <hash_map>
+#include <boost/unordered_map.hpp>
 #include <tox.hxx>
 class String;
 
@@ -95,11 +95,11 @@ SW_DLLPUBLIC const char * dbg_out(const SwNumRuleTbl & rTbl);
 SW_DLLPUBLIC const char * dbg_out(const SwNodeRange & rRange);
 
 template<typename tKey, typename tMember, typename fHashFunction>
-String lcl_dbg_out(const std::hash_map<tKey, tMember, fHashFunction> & rMap)
+String lcl_dbg_out(const boost::unordered_map<tKey, tMember, fHashFunction> & rMap)
 {
     String aResult("[", RTL_TEXTENCODING_ASCII_US);
 
-    typename std::hash_map<tKey, tMember, fHashFunction>::const_iterator aIt;
+    typename boost::unordered_map<tKey, tMember, fHashFunction>::const_iterator aIt;
 
     for (aIt = rMap.begin(); aIt != rMap.end(); aIt++)
     {
@@ -119,7 +119,7 @@ String lcl_dbg_out(const std::hash_map<tKey, tMember, fHashFunction> & rMap)
 }
 
 template<typename tKey, typename tMember, typename fHashFunction>
-const char * dbg_out(const std::hash_map<tKey, tMember, fHashFunction> & rMap)
+const char * dbg_out(const boost::unordered_map<tKey, tMember, fHashFunction> & rMap)
 {
     return dbg_out(lcl_dbg_out(rMap));
 }
diff --git a/sw/inc/doc.hxx b/sw/inc/doc.hxx
index 39b4c10..4b7234e 100644
--- a/sw/inc/doc.hxx
+++ b/sw/inc/doc.hxx
@@ -80,7 +80,7 @@ class SwList;
 #include <com/sun/star/linguistic2/XProofreadingIterator.hpp>
 #include <com/sun/star/script/vba/XVBAEventProcessor.hpp>
 
-#include <hash_map>
+#include <boost/unordered_map.hpp>
 #include <stringhash.hxx>
 
 #include <svtools/embedhlp.hxx>
@@ -363,9 +363,9 @@ class SW_DLLPUBLIC SwDoc :
     mutable SwNumRuleTbl    *pNumRuleTbl;   // List of all named NumRules.
 
     // Hash map to find numrules by name
-    mutable std::hash_map<String, SwNumRule *, StringHash> maNumRuleMap;
+    mutable boost::unordered_map<String, SwNumRule *, StringHash> maNumRuleMap;
 
-    typedef std::hash_map< String, SwList*, StringHash > tHashMapForLists;
+    typedef boost::unordered_map< String, SwList*, StringHash > tHashMapForLists;
     // container to hold the lists of the text document
     tHashMapForLists maLists;
     // relation between list style and its default list
diff --git a/sw/inc/numrule.hxx b/sw/inc/numrule.hxx
index 7bd6443..dafa1b5 100644
--- a/sw/inc/numrule.hxx
+++ b/sw/inc/numrule.hxx
@@ -39,7 +39,7 @@
 #include <errhdl.hxx> 		// Fuer die inline ASSERT
 #include <error.h>			// Fuer die inline ASSERT
 #include <hints.hxx>
-#include <hash_map>
+#include <boost/unordered_map.hpp>
 #include <stringhash.hxx>
 class SwNodeNum;
 #include <SwNumberTreeTypes.hxx>
@@ -127,8 +127,8 @@ private:
     /** container for associated paragraph styles */
     tParagraphStyleList maParagraphStyleList;
 
-    /** hash_map containing "name->rule" relation */
-    std::hash_map<String, SwNumRule *, StringHash> * pNumRuleMap;
+    /** boost::unordered_map containing "name->rule" relation */
+    boost::unordered_map<String, SwNumRule *, StringHash> * pNumRuleMap;
 
     String sName;
     SwNumRuleType eRuleType;
@@ -206,7 +206,7 @@ public:
        @param pNumRuleMap      map to register in
      */
     void SetNumRuleMap(
-                std::hash_map<String, SwNumRule *, StringHash>* pNumRuleMap );
+                boost::unordered_map<String, SwNumRule *, StringHash>* pNumRuleMap );
 
     static char* GetOutlineRuleName() { return pDefOutlineName; }
 
diff --git a/sw/source/core/access/accpara.hxx b/sw/source/core/access/accpara.hxx
index 4d72d43..cc27c42 100644
--- a/sw/source/core/access/accpara.hxx
+++ b/sw/source/core/access/accpara.hxx
@@ -35,7 +35,7 @@
 #include <com/sun/star/accessibility/XAccessibleTextMarkup.hpp>
 #include <com/sun/star/accessibility/XAccessibleMultiLineText.hpp>
 #include <com/sun/star/accessibility/XAccessibleTextAttributes.hpp>
-#include <hash_map>
+#include <boost/unordered_map.hpp>
 #include <accselectionhelper.hxx>
 #include <calbck.hxx> // #i108125#
 
@@ -53,7 +53,7 @@ namespace com { namespace sun { namespace star {
     namespace accessibility { class XAccessibleHyperlink; }
 } } }
 
-typedef ::std::hash_map< ::rtl::OUString,
+typedef ::boost::unordered_map< ::rtl::OUString,
                          ::com::sun::star::beans::PropertyValue,
                          ::rtl::OUStringHash,
                          ::std::equal_to< ::rtl::OUString > > tAccParaPropValMap;
diff --git a/sw/source/core/doc/docnew.cxx b/sw/source/core/doc/docnew.cxx
index 8153957..7c435cb 100644
--- a/sw/source/core/doc/docnew.cxx
+++ b/sw/source/core/doc/docnew.cxx
@@ -634,7 +634,7 @@ SwDoc::~SwDoc()
     delete pNumRuleTbl;
 
     {
-        for ( std::hash_map< String, SwList*, StringHash >::iterator
+        for ( boost::unordered_map< String, SwList*, StringHash >::iterator
                                                     aListIter = maLists.begin();
               aListIter != maLists.end();
               ++aListIter )
diff --git a/sw/source/core/doc/docnum.cxx b/sw/source/core/doc/docnum.cxx
index 30b03a5..8d5ef74 100644
--- a/sw/source/core/doc/docnum.cxx
+++ b/sw/source/core/doc/docnum.cxx
@@ -2485,7 +2485,7 @@ SwList* SwDoc::getListByName( const String sListId ) const
 {
     SwList* pList = 0;
 
-    std::hash_map< String, SwList*, StringHash >::const_iterator
+    boost::unordered_map< String, SwList*, StringHash >::const_iterator
                                             aListIter = maLists.find( sListId );
     if ( aListIter != maLists.end() )
     {
@@ -2535,7 +2535,7 @@ SwList* SwDoc::getListForListStyle( const String sListStyleName ) const
 {
     SwList* pList = 0;
 
-    std::hash_map< String, SwList*, StringHash >::const_iterator
+    boost::unordered_map< String, SwList*, StringHash >::const_iterator
                             aListIter = maListStyleLists.find( sListStyleName );
     if ( aListIter != maListStyleLists.end() )
     {
diff --git a/sw/source/core/doc/number.cxx b/sw/source/core/doc/number.cxx
index e89903f..d0f5c62 100644
--- a/sw/source/core/doc/number.cxx
+++ b/sw/source/core/doc/number.cxx
@@ -54,7 +54,7 @@
 #include <numrule.hxx>
 #include <SwNodeNum.hxx>
 
-#include <hash_map>
+#include <boost/unordered_map.hpp>
 
 #include <list.hxx>
 #include <algorithm>
@@ -164,7 +164,7 @@ void SwNumRule::RemoveTxtNode( SwTxtNode& rTxtNode )
 }
 
 
-void SwNumRule::SetNumRuleMap(std::hash_map<String, SwNumRule *, StringHash> *
+void SwNumRule::SetNumRuleMap(boost::unordered_map<String, SwNumRule *, StringHash> *
                               _pNumRuleMap)
 {
     pNumRuleMap = _pNumRuleMap;
diff --git a/sw/source/core/doc/swstylemanager.cxx b/sw/source/core/doc/swstylemanager.cxx
index 1d86fe1..cfb5b9d 100644
--- a/sw/source/core/doc/swstylemanager.cxx
+++ b/sw/source/core/doc/swstylemanager.cxx
@@ -31,7 +31,7 @@
 
 
 #include "swstylemanager.hxx"
-#include <hash_map>
+#include <boost/unordered_map.hpp>
 #include <svl/stylepool.hxx>
 #include <doc.hxx>
 #include <charfmt.hxx>
@@ -39,7 +39,7 @@
 #include <swtypes.hxx>
 #include <istyleaccess.hxx>
 
-typedef ::std::hash_map< const ::rtl::OUString,
+typedef ::boost::unordered_map< const ::rtl::OUString,
                          StylePool::SfxItemSet_Pointer_t,
                          ::rtl::OUStringHash,
                          ::std::equal_to< ::rtl::OUString > > SwStyleNameCache;
diff --git a/sw/source/core/inc/layouter.hxx b/sw/source/core/inc/layouter.hxx
index 8e19f9a..9fb7d94 100644
--- a/sw/source/core/inc/layouter.hxx
+++ b/sw/source/core/inc/layouter.hxx
@@ -55,7 +55,7 @@ class SwFrm;
 // <--
 // --> OD 2006-05-10 #i65250#
 #include <swtypes.hxx>
-#include <hash_map>
+#include <boost/unordered_map.hpp>
 class SwFlowFrm;
 class SwLayoutFrm;
 // <--
@@ -118,7 +118,7 @@ private:
                    p_key1.mnFreeSpaceInNewUpper == p_key2.mnFreeSpaceInNewUpper;
         }
     };
-    std::hash_map< const tMoveBwdLayoutInfoKey, sal_uInt16,
+    boost::unordered_map< const tMoveBwdLayoutInfoKey, sal_uInt16,
                    fMoveBwdLayoutInfoKeyHash,
                    fMoveBwdLayoutInfoKeyEq > maMoveBwdLayoutInfo;
     // <--
diff --git a/sw/source/core/unocore/unocoll.cxx b/sw/source/core/unocore/unocoll.cxx
index f897018..073fe10 100644
--- a/sw/source/core/unocore/unocoll.cxx
+++ b/sw/source/core/unocore/unocoll.cxx
@@ -173,7 +173,7 @@ public:
     }
 };
 
-typedef std::hash_map< rtl::OUString, rtl::OUString, rtl::OUStringHash > StringHashMap;
+typedef boost::unordered_map< rtl::OUString, rtl::OUString, rtl::OUStringHash > StringHashMap;
 class SwVbaProjectNameProvider : public ::cppu::WeakImplHelper1< container::XNameContainer >
 {
     SwDocShell* mpDocShell;
diff --git a/sw/source/filter/ww8/WW8TableInfo.hxx b/sw/source/filter/ww8/WW8TableInfo.hxx
index 9dc1048..da1eea1 100644
--- a/sw/source/filter/ww8/WW8TableInfo.hxx
+++ b/sw/source/filter/ww8/WW8TableInfo.hxx
@@ -28,7 +28,7 @@
  
 #ifndef WW8_TABLE_INFO_HXX
 #define WW8_TABLE_INFO_HXX
-#include <hash_map>
+#include <boost/unordered_map.hpp>
 #include <string>
 #include <map>
 #include <set>
@@ -253,13 +253,13 @@ public:
 class WW8TableInfo
 {
     friend class WW8TableNodeInfoInner;
-    typedef hash_map<const SwNode *, WW8TableNodeInfo::Pointer_t, hashNode > Map_t;
+    typedef boost::unordered_map<const SwNode *, WW8TableNodeInfo::Pointer_t, hashNode > Map_t;
     Map_t mMap;
 
-    typedef hash_map<const SwTable *, WW8TableCellGrid::Pointer_t, hashTable > CellGridMap_t;
+    typedef boost::unordered_map<const SwTable *, WW8TableCellGrid::Pointer_t, hashTable > CellGridMap_t;
     CellGridMap_t mCellGridMap;
 
-    typedef hash_map<const SwTable *, const SwNode *, hashTable > FirstInTableMap_t;
+    typedef boost::unordered_map<const SwTable *, const SwNode *, hashTable > FirstInTableMap_t;
     FirstInTableMap_t mFirstInTableMap;    
 
     WW8TableNodeInfo *
diff --git a/sw/source/filter/xml/xmltbli.cxx b/sw/source/filter/xml/xmltbli.cxx
index 8222fef..a088ffe 100644
--- a/sw/source/filter/xml/xmltbli.cxx
+++ b/sw/source/filter/xml/xmltbli.cxx
@@ -78,7 +78,7 @@ using namespace ::com::sun::star::frame;
 using namespace ::com::sun::star::table;
 using namespace ::com::sun::star::xml::sax;
 using namespace ::xmloff::token;
-using ::std::hash_map;
+using ::boost::unordered_map;
 using rtl::OUString;
 
 enum SwXMLTableElemTokens
diff --git a/sw/source/filter/xml/xmltbli.hxx b/sw/source/filter/xml/xmltbli.hxx
index 4f991d9..32622dc 100644
--- a/sw/source/filter/xml/xmltbli.hxx
+++ b/sw/source/filter/xml/xmltbli.hxx
@@ -32,7 +32,7 @@
 #include <xmloff/XMLTextTableContext.hxx>
 
 // STL include
-#include <hash_map>
+#include <boost/unordered_map.hpp>
 
 #if !defined(_SVSTDARR_USHORTS_DECL) || !defined(_SVSTDARR_BOOLS_DECL) || !defined(_SVSTDARR_STRINGSDTOR_DECL)
 #define _SVSTDARR_USHORTS
@@ -88,7 +88,7 @@ class SwXMLTableContext : public XMLTextTableContext
 
     // hash map of shared format, indexed by the (XML) style name,
     // the column width, and protection flag
-    typedef std::hash_map<TableBoxIndex,SwTableBoxFmt*,
+    typedef boost::unordered_map<TableBoxIndex,SwTableBoxFmt*,
                           TableBoxIndexHasher> map_BoxFmt;
     map_BoxFmt* pSharedBoxFormats;
 
diff --git a/sw/source/ui/vba/vbadocumentproperties.cxx b/sw/source/ui/vba/vbadocumentproperties.cxx
index a8d7666..43d16f4 100644
--- a/sw/source/ui/vba/vbadocumentproperties.cxx
+++ b/sw/source/ui/vba/vbadocumentproperties.cxx
@@ -236,7 +236,7 @@ public:
 };
 
 
-typedef std::hash_map< sal_Int32, DocPropInfo > MSOIndexToOODocPropInfo;
+typedef boost::unordered_map< sal_Int32, DocPropInfo > MSOIndexToOODocPropInfo;
 
 class BuiltInIndexHelper
 {
@@ -482,7 +482,7 @@ typedef ::cppu::WeakImplHelper3< com::sun::star::container::XIndexAccess
         ,com::sun::star::container::XEnumerationAccess
         > PropertiesImpl_BASE;
 
-typedef std::hash_map< sal_Int32, uno::Reference< XDocumentProperty > > DocProps;
+typedef boost::unordered_map< sal_Int32, uno::Reference< XDocumentProperty > > DocProps;
 
 typedef ::cppu::WeakImplHelper1< com::sun::star::container::XEnumeration > DocPropEnumeration_BASE;
 class DocPropEnumeration : public DocPropEnumeration_BASE
@@ -504,7 +504,7 @@ public:
     }
 };
 
-typedef std::hash_map< rtl::OUString, uno::Reference< XDocumentProperty >, ::rtl::OUStringHash, ::std::equal_to< ::rtl::OUString > > DocPropsByName;
+typedef boost::unordered_map< rtl::OUString, uno::Reference< XDocumentProperty >, ::rtl::OUStringHash, ::std::equal_to< ::rtl::OUString > > DocPropsByName;
 
 class BuiltInPropertiesImpl : public PropertiesImpl_BASE
 {
diff --git a/sw/source/ui/vba/vbadocumentproperties.hxx b/sw/source/ui/vba/vbadocumentproperties.hxx
index 7b49d5c..25cc54b 100644
--- a/sw/source/ui/vba/vbadocumentproperties.hxx
+++ b/sw/source/ui/vba/vbadocumentproperties.hxx
@@ -31,7 +31,7 @@
 #include <ooo/vba/XDocumentProperties.hpp>
 #include <com/sun/star/frame/XModel.hpp>
 #include <vbahelper/vbacollectionimpl.hxx>
-#include <hash_map>
+#include <boost/unordered_map.hpp>
 
 typedef CollTestImplHelper< ov::XDocumentProperties > SwVbaDocumentproperties_BASE;
 
diff --git a/sw/source/ui/vba/vbadocuments.cxx b/sw/source/ui/vba/vbadocuments.cxx
index 6540a3f..fd42b8e 100644
--- a/sw/source/ui/vba/vbadocuments.cxx
+++ b/sw/source/ui/vba/vbadocuments.cxx
@@ -56,7 +56,7 @@
 #include "vbadocuments.hxx"
 #include <vbahelper/vbahelper.hxx>
 
-#include <hash_map>
+#include <boost/unordered_map.hpp>
 #include <osl/file.hxx>
 using namespace ::ooo::vba;
 using namespace ::com::sun::star;
diff --git a/sw/source/ui/vba/vbafont.cxx b/sw/source/ui/vba/vbafont.cxx
index 91fa3d6..4553c47 100644
--- a/sw/source/ui/vba/vbafont.cxx
+++ b/sw/source/ui/vba/vbafont.cxx
@@ -2,7 +2,7 @@
 #include "vbafont.hxx"
 #include <com/sun/star/awt/FontUnderline.hpp>
 #include <ooo/vba/word/WdUnderline.hpp>
-#include <hash_map>
+#include <boost/unordered_map.hpp>
 #include <sal/macros.h>
 #include <ooo/vba/word/WdColorIndex.hpp>
 
@@ -39,7 +39,7 @@ static MapPair UnderLineTable[] = {
         { word::WdUnderline::wdUnderlineDashLongHeavy, com::sun::star::awt::FontUnderline::BOLDLONGDASH },
 };
 
-typedef std::hash_map< sal_Int32, sal_Int32 > ConstToConst;
+typedef boost::unordered_map< sal_Int32, sal_Int32 > ConstToConst;
 class UnderLineMapper
 {
     ConstToConst MSO2OOO;


More information about the Libreoffice-commits mailing list
diff --git a/sw/source/filter/ww8/hash_wrap.hxx b/sw/source/filter/ww8/hash_wrap.hxx
index ff71be2..aa595f1 100644
--- a/sw/source/filter/ww8/hash_wrap.hxx
+++ b/sw/source/filter/ww8/hash_wrap.hxx
@@ -26,16 +26,16 @@
  *
  ************************************************************************/
 
 //this is a shameless rip from sortedarray.hxx but changed to hash_set
 
 #ifndef WW_HASH_WRAP_HXX
 #define WW_HASH_WRAP_HXX
 
-#include <hash_set>
+#include <boost/unordered_set.hpp>
 #include <tools/debug.hxx>
 #include <errhdl.hxx>       // OSL_ENSURE()
 
 //simple wrapper around hash_set to behave like sorted array
 namespace ww
 {
     /** simple template that manages a hash
@@ -47,7 +47,7 @@ namespace ww
     template<class C, class HashFcn = std::hash<C> > class WrappedHash
     {
     private:
-        std::hash_set<C, HashFcn> mHashSet;
+        boost::unordered_set<C, HashFcn> mHashSet;
 
         //No copying
         WrappedHash(const WrappedHash&);
@@ -56,7 +56,7 @@ namespace ww
         //Find an entry, return its address if found and 0 if not
         const C* search(C aSrch) const
         {
-            typename std::hash_set<C, HashFcn>::const_iterator it;
+            typename boost::unordered_set<C, HashFcn>::const_iterator it;
             it= mHashSet.find(aSrch);
             if (it != mHashSet.end())
                 return &(*it);
@@ -26,16 +26,16 @@
  ************************************************************************/
 
-//this is a shameless rip from sortedarray.hxx but changed to hash_set
+//this is a shameless rip from sortedarray.hxx but changed to boost::unordered_set
 
 #ifndef WW_HASH_WRAP_HXX
@@ -26,16 +26,16 @@
 #include <errhdl.hxx>       // OSL_ENSURE()
 
-//simple wrapper around hash_set to behave like sorted array
+//simple wrapper around boost::unordered_set to behave like sorted array
 namespace ww
 {